Struct percent_encoding::SIMPLE_ENCODE_SET
source · [−]pub struct SIMPLE_ENCODE_SET;Expand description
This encode set is used for the path of cannot-be-a-base URLs.
All ASCII charcters less than hexidecimal 20 and greater than 7E are encoded. This includes special charcters such as line feed, carriage return, NULL, etc.